==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/fr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Commentaires",
    "Edit comment" : "Modifier le commentaire",
    "Delete comment" : "Supprimer le commentaire",
    "New comment …" : "Nouveau commentaire...",
    "Post" : "Poster",
    "Cancel" : "Annuler",
    "[Deleted user]" : "[Utilisateur supprimé]",
    "No comments yet, start the conversation!" : "Il n'y a aucun commentaire, démarrez la conversation !",
    "More comments …" : "Plus de commentaires ...",
    "Save" : "Enregistrer",
    "Allowed characters {count} of {max}" : "{count} sur {max} caractères autorisés",
    "Error occurred while retrieving comment with ID {id}" : "Une erreur est survenue lors de la récupération du commentaire avec l'ID {id}",
    "Error occurred while updating comment with id {id}" : "Une erreur est survenue lors de la mise à jour du commentaire avec l'id {id}",
    "Error occurred while posting comment" : "Une erreur est survenue lors de l'envoi du commentaire",
    "_%n unread comment_::_%n unread comments_" : ["%n commentaire non lu","%n commentaires non lus"],
    "Comment" : "Commenter",
    "You commented" : "Vous avez commenté",
    "%1$s commented" : "%1$s a commenté",
    "{author} commented" : "{author} a commenté",
    "You commented on %1$s" : "Vous avez commenté %1$s",
    "You commented on {file}" : "Vous avez commenté {file}",
    "%1$s commented on %2$s" : "%1$s a commenté %2$s",
    "{author} commented on {file}" : "{author} a commenté sur {file}",
    "<strong>Comments</strong> for files" : "<strong>Commentaires</strong> sur les fichiers",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Vous avez été mentionné sur \"%s\", dans un commentaire par un utilisateur qui a été supprimé depuis lors.",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Vous avez été mentionné sur \"{file}\", dans un commentaire par un utilisateur qui a été supprimé depuis lors.",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s vous a mentionné⋅e dans un commentaire sur “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} vous a mentionné⋅e dans un commentaire sur “{file}”",
    "Files app plugin to add comments to files" : "Plugin Fichiers app pour ajouter des commentaires aux fichiers",
    "Unknown user" : "Utilisateur·trice inconnu·e",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un·e utilisateur·trice (maintenant supprimé·e) vous a mentionné·e dans un commentaire sur “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un·e utilisateur·trice (maintenant supprimé·e) vous a mentionné·e dans un commentaire sur “{file}”"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/fr.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Modifier le commentaire",
    "Delete comment" : "Supprimer le commentaire",
    "New comment …" : "Nouveau commentaire...",
    "Post" : "Poster",
    "Cancel" : "Annuler",
    "[Deleted user]" : "[Utilisateur supprimé]",
    "Comments" : "Commentaires",
    "No comments yet, start the conversation!" : "Il n'y a aucun commentaire, démarrez la conversation !",
    "More comments …" : "Plus de commentaires ...",
    "Save" : "Enregistrer",
    "Allowed characters {count} of {max}" : "{count} sur {max} caractères autorisés",
    "Error occurred while retrieving comment with ID {id}" : "Une erreur est survenue lors de la récupération du commentaire avec l'ID {id}",
    "Error occurred while updating comment with id {id}" : "Une erreur est survenue lors de la mise à jour du commentaire avec l'id {id}",
    "Error occurred while posting comment" : "Une erreur est survenue lors de l'envoi du commentaire",
    "_%n unread comment_::_%n unread comments_" : ["%n commentaire non lu","%n commentaires non lus"],
    "Comment" : "Commenter",
    "You commented" : "Vous avez commenté",
    "%1$s commented" : "%1$s a commenté",
    "{author} commented" : "{author} a commenté",
    "You commented on %1$s" : "Vous avez commenté %1$s",
    "You commented on {file}" : "Vous avez commenté {file}",
    "%1$s commented on %2$s" : "%1$s a commenté %2$s",
    "{author} commented on {file}" : "{author} a commenté sur {file}",
    "<strong>Comments</strong> for files" : "<strong>Commentaires</strong> sur les fichiers",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Vous avez été mentionné sur \"{file}\", dans un commentaire par un utilisateur qui a été supprimé depuis lors.",
    "{user} mentioned you in a comment on “{file}”" : "{user} vous a mentionné⋅e dans un commentaire sur “{file}”",
    "Files app plugin to add comments to files" : "Plugin Fichiers app pour ajouter des commentaires aux fichiers",
    "Unknown user" : "Utilisateur·trice inconnu·e",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un·e utilisateur·trice (maintenant supprimé·e) vous a mentionné·e dans un commentaire sur “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un·e utilisateur·trice (maintenant supprimé·e) vous a mentionné·e dans un commentaire sur “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s vous a mentionné⋅e dans un commentaire sur “%2$s”",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Vous avez été mentionné sur \"%s\", dans un commentaire par un utilisateur qui a été supprimé depuis lors."
},
"nplurals=2; plural=(n > 1);");
